pub struct ServerCommand;Expand description
Built-in server command that runs all registered daemons.
This command starts the application in server mode, running all registered daemon services until a shutdown signal (Ctrl+C) is received.