pub trait RunDaemonsExt {
// Required method
fn run_daemons(
self,
shutdown: CancellationToken,
) -> impl Future<Output = Result<(), StdError>> + Send;
}Expand description
Runs every registered Daemon until shutdown.
Required Methods
Sourcefn run_daemons(
self,
shutdown: CancellationToken,
) -> impl Future<Output = Result<(), StdError>> + Send
fn run_daemons( self, shutdown: CancellationToken, ) -> impl Future<Output = Result<(), StdError>> + Send
Runs all registered daemons concurrently.
Returns once the shutdown token is cancelled or the first daemon
returns; in either case the remaining daemons are signalled to stop and
awaited. Returns immediately if no daemons were registered.
Errors
Returns the first error reported by a daemon, or the join error if a daemon task panics.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".